@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (c) 2015, Alcatel-Lucent Inc
+# Copyright (c) 2015, Alcatel-Lucent Inc, 2017 Nokia
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -26,6 +26,13 @@
 # SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
+
+
+from .fetchers import NUMetadatasFetcher
+
+
+from .fetchers import NUGlobalMetadatasFetcher
+
 from bambou import NURESTObject
 
 
@@ -40,6 +47,13 @@ class NULicenseStatus(NURESTObject):
     __resource_name__ = "licensestatus"
 
     
+    ## Constants
+    
+    CONST_ENTITY_SCOPE_GLOBAL = "GLOBAL"
+    
+    CONST_ENTITY_SCOPE_ENTERPRISE = "ENTERPRISE"
+    
+    
 
     def __init__(self, **kwargs):
         """ Initializes a LicenseStatus instance
@@ -59,6 +73,7 @@ class NULicenseStatus(NURESTObject):
         # Read/Write Attributes
         
         self._accumulate_licenses_enabled = None
+        self._entity_scope = None
         self._total_licensed_avrsgs_count = None
         self._total_licensed_avrss_count = None
         self._total_licensed_gateways_count = None
@@ -68,15 +83,21 @@ class NULicenseStatus(NURESTObject):
         self._total_licensed_used_avrss_count = None
         self._total_licensed_used_nics_count = None
         self._total_licensed_used_nsgs_count = None
+        self._total_licensed_used_vdfgs_count = None
+        self._total_licensed_used_vdfs_count = None
         self._total_licensed_used_vms_count = None
         self._total_licensed_used_vrsgs_count = None
         self._total_licensed_used_vrss_count = None
+        self._total_licensed_vdfgs_count = None
+        self._total_licensed_vdfs_count = None
         self._total_licensed_vms_count = None
         self._total_licensed_vrsgs_count = None
         self._total_licensed_vrss_count = None
         self._total_used_gateways_count = None
+        self._external_id = None
         
         self.expose_attribute(local_name="accumulate_licenses_enabled", remote_name="accumulateLicensesEnabled", attribute_type=bool, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="entity_scope", remote_name="entityScope", attribute_type=str, is_required=False, is_unique=False, choices=[u'ENTERPRISE', u'GLOBAL'])
         self.expose_attribute(local_name="total_licensed_avrsgs_count", remote_name="totalLicensedAVRSGsCount", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="total_licensed_avrss_count", remote_name="totalLicensedAVRSsCount", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="total_licensed_gateways_count", remote_name="totalLicensedGatewaysCount", attribute_type=int, is_required=False, is_unique=False)
@@ -86,13 +107,27 @@ class NULicenseStatus(NURESTObject):
         self.expose_attribute(local_name="total_licensed_used_avrss_count", remote_name="totalLicensedUsedAVRSsCount", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="total_licensed_used_nics_count", remote_name="totalLicensedUsedNICsCount", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="total_licensed_used_nsgs_count", remote_name="totalLicensedUsedNSGsCount", attribute_type=int, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="total_licensed_used_vdfgs_count", remote_name="totalLicensedUsedVDFGsCount", attribute_type=int, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="total_licensed_used_vdfs_count", remote_name="totalLicensedUsedVDFsCount", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="total_licensed_used_vms_count", remote_name="totalLicensedUsedVMsCount", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="total_licensed_used_vrsgs_count", remote_name="totalLicensedUsedVRSGsCount", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="total_licensed_used_vrss_count", remote_name="totalLicensedUsedVRSsCount", attribute_type=int, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="total_licensed_vdfgs_count", remote_name="totalLicensedVDFGsCount", attribute_type=int, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="total_licensed_vdfs_count", remote_name="totalLicensedVDFsCount", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="total_licensed_vms_count", remote_name="totalLicensedVMsCount", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="total_licensed_vrsgs_count", remote_name="totalLicensedVRSGsCount", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="total_licensed_vrss_count", remote_name="totalLicensedVRSsCount", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="total_used_gateways_count", remote_name="totalUsedGatewaysCount", attribute_type=int, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="external_id", remote_name="externalID", attribute_type=str, is_required=False, is_unique=True)
+        
+
+        # Fetchers
+        
+        
+        self.metadatas = NUMetadatasFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
+        self.global_metadatas = NUGlobalMetadatasFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
 
         self._compute_args(**kwargs)
@@ -126,6 +161,33 @@ class NULicenseStatus(NURESTObject):
         self._accumulate_licenses_enabled = value
 
     
+    @property
+    def entity_scope(self):
+        """ Get entity_scope value.
+
+            Notes:
+                Specify if scope of entity is Data center or Enterprise level
+
+                
+                This attribute is named `entityScope` in VSD API.
+                
+        """
+        return self._entity_scope
+
+    @entity_scope.setter
+    def entity_scope(self, value):
+        """ Set entity_scope value.
+
+            Notes:
+                Specify if scope of entity is Data center or Enterprise level
+
+                
+                This attribute is named `entityScope` in VSD API.
+                
+        """
+        self._entity_scope = value
+
+    
     @property
     def total_licensed_avrsgs_count(self):
         """ Get total_licensed_avrsgs_count value.
@@ -369,6 +431,60 @@ class NULicenseStatus(NURESTObject):
         self._total_licensed_used_nsgs_count = value
 
     
+    @property
+    def total_licensed_used_vdfgs_count(self):
+        """ Get total_licensed_used_vdfgs_count value.
+
+            Notes:
+                Indicates total used VDFG count for all the licenses in the system.
+
+                
+                This attribute is named `totalLicensedUsedVDFGsCount` in VSD API.
+                
+        """
+        return self._total_licensed_used_vdfgs_count
+
+    @total_licensed_used_vdfgs_count.setter
+    def total_licensed_used_vdfgs_count(self, value):
+        """ Set total_licensed_used_vdfgs_count value.
+
+            Notes:
+                Indicates total used VDFG count for all the licenses in the system.
+
+                
+                This attribute is named `totalLicensedUsedVDFGsCount` in VSD API.
+                
+        """
+        self._total_licensed_used_vdfgs_count = value
+
+    
+    @property
+    def total_licensed_used_vdfs_count(self):
+        """ Get total_licensed_used_vdfs_count value.
+
+            Notes:
+                Indicates total used VDF count for all the licenses in the system.
+
+                
+                This attribute is named `totalLicensedUsedVDFsCount` in VSD API.
+                
+        """
+        return self._total_licensed_used_vdfs_count
+
+    @total_licensed_used_vdfs_count.setter
+    def total_licensed_used_vdfs_count(self, value):
+        """ Set total_licensed_used_vdfs_count value.
+
+            Notes:
+                Indicates total used VDF count for all the licenses in the system.
+
+                
+                This attribute is named `totalLicensedUsedVDFsCount` in VSD API.
+                
+        """
+        self._total_licensed_used_vdfs_count = value
+
+    
     @property
     def total_licensed_used_vms_count(self):
         """ Get total_licensed_used_vms_count value.
@@ -450,6 +566,60 @@ class NULicenseStatus(NURESTObject):
         self._total_licensed_used_vrss_count = value
 
     
+    @property
+    def total_licensed_vdfgs_count(self):
+        """ Get total_licensed_vdfgs_count value.
+
+            Notes:
+                Indicates total VDFG count for all the licenses in the system
+
+                
+                This attribute is named `totalLicensedVDFGsCount` in VSD API.
+                
+        """
+        return self._total_licensed_vdfgs_count
+
+    @total_licensed_vdfgs_count.setter
+    def total_licensed_vdfgs_count(self, value):
+        """ Set total_licensed_vdfgs_count value.
+
+            Notes:
+                Indicates total VDFG count for all the licenses in the system
+
+                
+                This attribute is named `totalLicensedVDFGsCount` in VSD API.
+                
+        """
+        self._total_licensed_vdfgs_count = value
+
+    
+    @property
+    def total_licensed_vdfs_count(self):
+        """ Get total_licensed_vdfs_count value.
+
+            Notes:
+                Indicates total VDF count for all the licenses in the system
+
+                
+                This attribute is named `totalLicensedVDFsCount` in VSD API.
+                
+        """
+        return self._total_licensed_vdfs_count
+
+    @total_licensed_vdfs_count.setter
+    def total_licensed_vdfs_count(self, value):
+        """ Set total_licensed_vdfs_count value.
+
+            Notes:
+                Indicates total VDF count for all the licenses in the system
+
+                
+                This attribute is named `totalLicensedVDFsCount` in VSD API.
+                
+        """
+        self._total_licensed_vdfs_count = value
+
+    
     @property
     def total_licensed_vms_count(self):
         """ Get total_licensed_vms_count value.
@@ -536,7 +706,7 @@ class NULicenseStatus(NURESTObject):
         """ Get total_used_gateways_count value.
 
             Notes:
-                Indicates total VRS+VRSG+VRSB licenses used in the system
+                Indicates total VRS+VRSG+VRSB+VDF+VDFG licenses used in the system
 
                 
                 This attribute is named `totalUsedGatewaysCount` in VSD API.
@@ -549,7 +719,7 @@ class NULicenseStatus(NURESTObject):
         """ Set total_used_gateways_count value.
 
             Notes:
-                Indicates total VRS+VRSG+VRSB licenses used in the system
+                Indicates total VRS+VRSG+VRSB+VDF+VDFG licenses used in the system
 
                 
                 This attribute is named `totalUsedGatewaysCount` in VSD API.
@@ -558,5 +728,32 @@ class NULicenseStatus(NURESTObject):
         self._total_used_gateways_count = value
 
     
+    @property
+    def external_id(self):
+        """ Get external_id value.
+
+            Notes:
+                External object ID. Used for integration with third party systems
+
+                
+                This attribute is named `externalID` in VSD API.
+                
+        """
+        return self._external_id
+
+    @external_id.setter
+    def external_id(self, value):
+        """ Set external_id value.
+
+            Notes:
+                External object ID. Used for integration with third party systems
+
+                
+                This attribute is named `externalID` in VSD API.
+                
+        """
+        self._external_id = value
+
+    
 
     
\ No newline at end of file
