@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (c) 2015, Alcatel-Lucent Inc
+# Copyright (c) 2015, Alcatel-Lucent Inc, 2017 Nokia
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -27,9 +27,19 @@
 
 
 
+
 from .fetchers import NUL2DomainsFetcher
 
 
+from .fetchers import NUL4ServicesFetcher
+
+
+from .fetchers import NUL7applicationsignaturesFetcher
+
+
+from .fetchers import NUSaaSApplicationTypesFetcher
+
+
 from .fetchers import NUVCenterEAMConfigsFetcher
 
 
@@ -72,9 +82,15 @@ from .fetchers import NUCertificatesFetcher
 from .fetchers import NUMetadatasFetcher
 
 
+from .fetchers import NUNetconfProfilesFetcher
+
+
 from .fetchers import NUNetworkLayoutsFetcher
 
 
+from .fetchers import NUNetworkPerformanceMeasurementsFetcher
+
+
 from .fetchers import NUKeyServerMembersFetcher
 
 
@@ -96,12 +112,12 @@ from .fetchers import NUEgressACLEntryTemplatesFetcher
 from .fetchers import NUEgressACLTemplatesFetcher
 
 
+from .fetchers import NUEgressAdvFwdEntryTemplatesFetcher
+
+
 from .fetchers import NUDomainFIPAclTemplatesFetcher
 
 
-from .fetchers import NUFloatingIPACLTemplatesFetcher
-
-
 from .fetchers import NUEgressQOSPoliciesFetcher
 
 
@@ -117,9 +133,21 @@ from .fetchers import NULicenseStatusFetcher
 from .fetchers import NUMirrorDestinationsFetcher
 
 
+from .fetchers import NUVirtualFirewallPoliciesFetcher
+
+
+from .fetchers import NUVirtualFirewallRulesFetcher
+
+
 from .fetchers import NUSiteInfosFetcher
 
 
+from .fetchers import NUAllGatewaysFetcher
+
+
+from .fetchers import NUAllRedundancyGroupsFetcher
+
+
 from .fetchers import NUFloatingIpsFetcher
 
 
@@ -147,12 +175,18 @@ from .fetchers import NUVNFMetadatasFetcher
 from .fetchers import NUInfrastructureAccessProfilesFetcher
 
 
+from .fetchers import NUInfrastructureEVDFProfilesFetcher
+
+
 from .fetchers import NUInfrastructureGatewayProfilesFetcher
 
 
 from .fetchers import NUInfrastructureVscProfilesFetcher
 
 
+from .fetchers import NUVNFThresholdPoliciesFetcher
+
+
 from .fetchers import NUIngressACLEntryTemplatesFetcher
 
 
@@ -177,9 +211,15 @@ from .fetchers import NUJobsFetcher
 from .fetchers import NUPolicyGroupsFetcher
 
 
+from .fetchers import NUPolicyObjectGroupsFetcher
+
+
 from .fetchers import NUDomainsFetcher
 
 
+from .fetchers import NUCommandsFetcher
+
+
 from .fetchers import NUZonesFetcher
 
 
@@ -189,6 +229,9 @@ from .fetchers import NUContainersFetcher
 from .fetchers import NUContainerInterfacesFetcher
 
 
+from .fetchers import NUQosPolicersFetcher
+
+
 from .fetchers import NUCOSRemarkingPolicyTablesFetcher
 
 
@@ -201,6 +244,15 @@ from .fetchers import NURoutingPoliciesFetcher
 from .fetchers import NUUplinkRDsFetcher
 
 
+from .fetchers import NUApplicationsFetcher
+
+
+from .fetchers import NUApplicationperformancemanagementsFetcher
+
+
+from .fetchers import NUVRSsFetcher
+
+
 from .fetchers import NUVCenterVRSConfigsFetcher
 
 
@@ -210,6 +262,9 @@ from .fetchers import NUDSCPRemarkingPolicyTablesFetcher
 from .fetchers import NUUsersFetcher
 
 
+from .fetchers import NUUserContextsFetcher
+
+
 from .fetchers import NUNSGatewaysFetcher
 
 
@@ -219,6 +274,12 @@ from .fetchers import NUNSGatewayTemplatesFetcher
 from .fetchers import NUNSGGroupsFetcher
 
 
+from .fetchers import NUNSGInfosFetcher
+
+
+from .fetchers import NUNSGPatchProfilesFetcher
+
+
 from .fetchers import NUNSRedundantGatewayGroupsFetcher
 
 
@@ -246,6 +307,9 @@ from .fetchers import NUMultiCastChannelMapsFetcher
 from .fetchers import NUAutoDiscoveredGatewaysFetcher
 
 
+from .fetchers import NUOverlayMirrorDestinationsFetcher
+
+
 from .fetchers import NUSystemConfigsFetcher
 
 from bambou import NURESTRootObject
@@ -344,6 +408,15 @@ class NUMe(NURESTRootObject):
         self.l2_domains = NUL2DomainsFetcher.fetcher_with_object(parent_object=self, relationship="root")
         
         
+        self.l4_services = NUL4ServicesFetcher.fetcher_with_object(parent_object=self, relationship="root")
+        
+        
+        self.l7applicationsignatures = NUL7applicationsignaturesFetcher.fetcher_with_object(parent_object=self, relationship="root")
+        
+        
+        self.saa_s_application_types = NUSaaSApplicationTypesFetcher.fetcher_with_object(parent_object=self, relationship="root")
+        
+        
         self.vcenter_eam_configs = NUVCenterEAMConfigsFetcher.fetcher_with_object(parent_object=self, relationship="root")
         
         
@@ -383,12 +456,18 @@ class NUMe(NURESTRootObject):
         self.certificates = NUCertificatesFetcher.fetcher_with_object(parent_object=self, relationship="root")
         
         
-        self.metadatas = NUMetadatasFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        self.metadatas = NUMetadatasFetcher.fetcher_with_object(parent_object=self, relationship="root")
+        
+        
+        self.netconf_profiles = NUNetconfProfilesFetcher.fetcher_with_object(parent_object=self, relationship="root")
         
         
         self.network_layouts = NUNetworkLayoutsFetcher.fetcher_with_object(parent_object=self, relationship="root")
         
         
+        self.network_performance_measurements = NUNetworkPerformanceMeasurementsFetcher.fetcher_with_object(parent_object=self, relationship="root")
+        
+        
         self.key_server_members = NUKeyServerMembersFetcher.fetcher_with_object(parent_object=self, relationship="root")
         
         
@@ -410,12 +489,12 @@ class NUMe(NURESTRootObject):
         self.egress_acl_templates = NUEgressACLTemplatesFetcher.fetcher_with_object(parent_object=self, relationship="root")
         
         
+        self.egress_adv_fwd_entry_templates = NUEgressAdvFwdEntryTemplatesFetcher.fetcher_with_object(parent_object=self, relationship="root")
+        
+        
         self.domain_fip_acl_templates = NUDomainFIPAclTemplatesFetcher.fetcher_with_object(parent_object=self, relationship="root")
         
         
-        self.floating_ipacl_templates = NUFloatingIPACLTemplatesFetcher.fetcher_with_object(parent_object=self, relationship="root")
-        
-        
         self.egress_qos_policies = NUEgressQOSPoliciesFetcher.fetcher_with_object(parent_object=self, relationship="root")
         
         
@@ -431,9 +510,21 @@ class NUMe(NURESTRootObject):
         self.mirror_destinations = NUMirrorDestinationsFetcher.fetcher_with_object(parent_object=self, relationship="root")
         
         
+        self.virtual_firewall_policies = NUVirtualFirewallPoliciesFetcher.fetcher_with_object(parent_object=self, relationship="root")
+        
+        
+        self.virtual_firewall_rules = NUVirtualFirewallRulesFetcher.fetcher_with_object(parent_object=self, relationship="root")
+        
+        
         self.site_infos = NUSiteInfosFetcher.fetcher_with_object(parent_object=self, relationship="root")
         
         
+        self.all_gateways = NUAllGatewaysFetcher.fetcher_with_object(parent_object=self, relationship="root")
+        
+        
+        self.all_redundancy_groups = NUAllRedundancyGroupsFetcher.fetcher_with_object(parent_object=self, relationship="root")
+        
+        
         self.floating_ips = NUFloatingIpsFetcher.fetcher_with_object(parent_object=self, relationship="root")
         
         
@@ -461,12 +552,18 @@ class NUMe(NURESTRootObject):
         self.infrastructure_access_profiles = NUInfrastructureAccessProfilesFetcher.fetcher_with_object(parent_object=self, relationship="root")
         
         
+        self.infrastructure_evdf_profiles = NUInfrastructureEVDFProfilesFetcher.fetcher_with_object(parent_object=self, relationship="root")
+        
+        
         self.infrastructure_gateway_profiles = NUInfrastructureGatewayProfilesFetcher.fetcher_with_object(parent_object=self, relationship="root")
         
         
         self.infrastructure_vsc_profiles = NUInfrastructureVscProfilesFetcher.fetcher_with_object(parent_object=self, relationship="root")
         
         
+        self.vnf_threshold_policies = NUVNFThresholdPoliciesFetcher.fetcher_with_object(parent_object=self, relationship="root")
+        
+        
         self.ingress_acl_entry_templates = NUIngressACLEntryTemplatesFetcher.fetcher_with_object(parent_object=self, relationship="root")
         
         
@@ -491,9 +588,15 @@ class NUMe(NURESTRootObject):
         self.policy_groups = NUPolicyGroupsFetcher.fetcher_with_object(parent_object=self, relationship="root")
         
         
+        self.policy_object_groups = NUPolicyObjectGroupsFetcher.fetcher_with_object(parent_object=self, relationship="root")
+        
+        
         self.domains = NUDomainsFetcher.fetcher_with_object(parent_object=self, relationship="root")
         
         
+        self.commands = NUCommandsFetcher.fetcher_with_object(parent_object=self, relationship="root")
+        
+        
         self.zones = NUZonesFetcher.fetcher_with_object(parent_object=self, relationship="root")
         
         
@@ -503,6 +606,9 @@ class NUMe(NURESTRootObject):
         self.container_interfaces = NUContainerInterfacesFetcher.fetcher_with_object(parent_object=self, relationship="root")
         
         
+        self.qos_policers = NUQosPolicersFetcher.fetcher_with_object(parent_object=self, relationship="root")
+        
+        
         self.cos_remarking_policy_tables = NUCOSRemarkingPolicyTablesFetcher.fetcher_with_object(parent_object=self, relationship="root")
         
         
@@ -515,6 +621,15 @@ class NUMe(NURESTRootObject):
         self.uplink_rds = NUUplinkRDsFetcher.fetcher_with_object(parent_object=self, relationship="root")
         
         
+        self.applications = NUApplicationsFetcher.fetcher_with_object(parent_object=self, relationship="root")
+        
+        
+        self.applicationperformancemanagements = NUApplicationperformancemanagementsFetcher.fetcher_with_object(parent_object=self, relationship="root")
+        
+        
+        self.vrss = NUVRSsFetcher.fetcher_with_object(parent_object=self, relationship="root")
+        
+        
         self.vcenter_vrs_configs = NUVCenterVRSConfigsFetcher.fetcher_with_object(parent_object=self, relationship="root")
         
         
@@ -524,6 +639,9 @@ class NUMe(NURESTRootObject):
         self.users = NUUsersFetcher.fetcher_with_object(parent_object=self, relationship="root")
         
         
+        self.user_contexts = NUUserContextsFetcher.fetcher_with_object(parent_object=self, relationship="root")
+        
+        
         self.ns_gateways = NUNSGatewaysFetcher.fetcher_with_object(parent_object=self, relationship="root")
         
         
@@ -533,6 +651,12 @@ class NUMe(NURESTRootObject):
         self.nsg_groups = NUNSGGroupsFetcher.fetcher_with_object(parent_object=self, relationship="root")
         
         
+        self.nsg_infos = NUNSGInfosFetcher.fetcher_with_object(parent_object=self, relationship="root")
+        
+        
+        self.nsg_patch_profiles = NUNSGPatchProfilesFetcher.fetcher_with_object(parent_object=self, relationship="root")
+        
+        
         self.ns_redundant_gateway_groups = NUNSRedundantGatewayGroupsFetcher.fetcher_with_object(parent_object=self, relationship="root")
         
         
@@ -560,6 +684,9 @@ class NUMe(NURESTRootObject):
         self.auto_discovered_gateways = NUAutoDiscoveredGatewaysFetcher.fetcher_with_object(parent_object=self, relationship="root")
         
         
+        self.overlay_mirror_destinations = NUOverlayMirrorDestinationsFetcher.fetcher_with_object(parent_object=self, relationship="root")
+        
+        
         self.system_configs = NUSystemConfigsFetcher.fetcher_with_object(parent_object=self, relationship="root")
         
 
@@ -653,7 +780,7 @@ class NUMe(NURESTRootObject):
         """ Get password value.
 
             Notes:
-                User password stored as a hash (SHA-1 encrpted)
+                User password in clear text. Password cannot be a single character asterisk (*)
 
                 
         """
@@ -664,7 +791,7 @@ class NUMe(NURESTRootObject):
         """ Set password value.
 
             Notes:
-                User password stored as a hash (SHA-1 encrpted)
+                User password in clear text. Password cannot be a single character asterisk (*)
 
                 
         """
@@ -807,7 +934,7 @@ class NUMe(NURESTRootObject):
         """ Get flow_collection_enabled value.
 
             Notes:
-                Enables flow statistics collection. It is needed for the VSS feature, and requires a valid VSS license. This option requires "statisticsEnabled".
+                Enables flow statistics collection. It is needed for the VSS feature, and requires a valid VSS license. This option requires 'statisticsEnabled'.
 
                 
                 This attribute is named `flowCollectionEnabled` in VSD API.
@@ -820,7 +947,7 @@ class NUMe(NURESTRootObject):
         """ Set flow_collection_enabled value.
 
             Notes:
-                Enables flow statistics collection. It is needed for the VSS feature, and requires a valid VSS license. This option requires "statisticsEnabled".
+                Enables flow statistics collection. It is needed for the VSS feature, and requires a valid VSS license. This option requires 'statisticsEnabled'.
 
                 
                 This attribute is named `flowCollectionEnabled` in VSD API.
@@ -1121,8 +1248,10 @@ class NUMe(NURESTRootObject):
 
     
     ## Custom methods
-    def save(self, async=False, callback=None):
+    def save(self, as_async=False, callback=None, **kwargs):
         """ """
-        super(NUMe, self).save(async=async, callback=callback, encrypted=False)
+        if 'async' in kwargs.keys() and not as_async:
+            as_async = kwargs['async']
+        super(NUMe, self).save(as_async=as_async, callback=callback, encrypted=False)
     
     
\ No newline at end of file
